<?php
// $Id $

/**
 * @file
 * uc_sf_account.ca.inc: Conditional Actions include file for uc_sf_account.module
 * Provides a Conditional Action used to export a Salesforce account and contact
 * based off of the Ubercart order data. Must run prior to the order export.
 *
 */

/**
 * Implementation of hook_ca_predicate().
 */
function uc_sf_account_ca_predicate() {
  $predicates = array();

  // Sets up a default predicate for exporting order purchaser account and contact
  $predicates['uc_checkout_salesforce_account_export'] = array(
    '#title' => t('Export order purchaser Account and Contact to Salesforce'),
    '#description' => t('Export order purchaser Account and Contact to Salesforce.'),
    '#class' => 'uc_salesforce',
    '#status' => 1,
    '#weight' => 11,   // must come after uc_checkout_salesforce_order_ocr_export, which is 10
    '#trigger' => 'uc_checkout_complete',
    '#actions' => array(
      array(
        '#name' => 'uc_sf_account_salesforce_export',
        '#title' => t('Export the order purchaser Account and Contact to Salesforce'),
        '#argument_map' => array(
          'order' => 'order',
        ),
        '#settings' => array(
          'order_status' => 'completed',
        ),
      ),
    ),
  );
	// Sets up a default predicate for exporting order purchaser account and contact
  $predicates['uc_checkout_salesforce_purchaser_ocr_export'] = array(
    '#title' => t('Export order purchaser OCR to Salesforce'),
    '#description' => t('Export order purchaser OpportunityContactRole to Salesforce.'),
    '#class' => 'uc_salesforce',
    '#status' => 1,
    '#weight' => 12,   // must come after uc_checkout_salesforce_account_export, which is 11
    '#trigger' => 'uc_checkout_complete',
    '#actions' => array(
      array(
        '#name' => 'uc_sf_account_salesforce_ocr_export',
        '#title' => t('Export the order purchaser OpportunityContactRole to Salesforce'),
        '#argument_map' => array(
          'order' => 'order',
        ),
        '#settings' => array(
          'order_status' => 'completed',
        ),
      ),
    ),
  );

  return $predicates;
}

/**
 * Implementation of hook_ca_action().
 */
function uc_sf_account_ca_action() {
  $order_arg = array(
    '#entity' => 'uc_order',
    '#title' => t('Order'),
  );

  $actions['uc_sf_account_salesforce_export'] = array(
    '#title' => t('Export the order purchaser Account and Contact to Salesforce'),
    '#category' => t('Salesforce'),
    '#callback' => 'uc_sf_account_export_action',
    '#arguments' => array(
      'order' => $order_arg,
    ),
  );
	
	$actions['uc_sf_account_salesforce_ocr_export'] = array(
    '#title' => t('Export the order purchaser OpportunityContactRole to Salesforce'),
    '#category' => t('Salesforce'),
    '#callback' => 'uc_sf_account_ocr_export_action',
    '#arguments' => array(
      'order' => $order_arg,
    ),
  );

  return $actions;
}
